<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>CircleCP</name>
    <message>
        <location filename="../CircleCP.js" line="+56"/>
        <source>Center</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wskaż środek
Łuk: środek, punkt, kąty</translatorcomment>
        <translation>Środek</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Point on circle or radius</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Punkt na okręgu lub promień</translation>
    </message>
    <message>
        <location filename="../CircleCPInit.js" line="+2"/>
        <source>&amp;Center, Point</source>
        <translatorcomment>--google--
ś&amp;rodek, punkt, kąty</translatorcomment>
        <translation>Ś&amp;rodek, punkt</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Draw circle from center and point on circle</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Rysuje okrąg od środka, przez punkt na okręgu</translation>
    </message>
</context>
</TS>
